# picpurify-python-client 

Python client library for accessing PicPurify moderation API.

Before starting, please make sure you have created an account on https://www.picpurify.com

## Installation 
```
pip install picpurify

```
## Documentation

API documentation can be found at <https://www.picpurify.com/api-services.html>.

